---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: false
description: "Open Web Calendar Privacy Policy"
---

# Privacy Policy

The Open Web Calendar does not collect any personal information from visitors
of the website.

Calendars may contain personal information. For the purpose of serving the
content fast, the calendar files are cached for a short while.
As expected, content of calendars is only processed to display them as a website.

## Documentation Website

This website contains the project documentation. It is hosted on
GitHub Pages. Their [Privacy Policy][privacy-policy] applies.

[privacy-policy]: https://docs.github.com/en/site-policy/privacy-policies/
